@@ -1,4 +1,5 @@
 from ..utils import get_singleton, sanitize_cache_key
+import warnings
 from copy import copy
 from django.core.cache import get_cache
 from django.core.exceptions import ImproperlyConfigured
@@ -160,34 +161,33 @@ class Celery(BaseAsync):
         _celery_task.delay(self, file, force=force)
 
 
-Async = Celery  # backwards compatibility
+# Stub class to preserve backwards compatibility and issue a warning
+class Async(Celery):
+    def __init__(self, *args, **kwargs):
+        message = '{path}.Async is deprecated. Use {path}.Celery instead.'
+        warnings.warn(message.format(path=__name__), DeprecationWarning)
+        super(Async, self).__init__(*args, **kwargs)
 
 
 try:
-    import django_rq
+    from django_rq import job
 except ImportError:
     pass
+else:
+    _rq_job = job('default', result_ttl=0)(_generate_file)
 
 
 class RQ(BaseAsync):
     """
     A backend that uses RQ to generate the images.
     """
-    queue_name = 'default'
-
     def __init__(self, *args, **kwargs):
         try:
             import django_rq
         except ImportError:
-            raise ImproperlyConfigured('You must install django_rq to use'
+            raise ImproperlyConfigured('You must install django-rq to use'
                                        ' imagekit.cachefiles.backends.RQ.')
         super(RQ, self).__init__(*args, **kwargs)
 
-    def get_queue(self):
-        # not caching property to avoid "can't pickle instancemethod objects",
-        # see https://github.com/nvie/rq/issues/189
-        return django_rq.get_queue(self.queue_name)
-
     def schedule_generation(self, file, force=False):
-        self.get_queue().enqueue(_generate_file, args=(self, file),
-                                 kwargs=dict(force=force), result_ttl=0)
+        _rq_job.delay(self, file, force=force)
