@@ -36,24 +36,11 @@ class DictStrategy(object):
             setattr(self, k, v)
 
 
-class StrategyWrapper(LazyObject):
-    def __init__(self, strategy):
-        if isinstance(strategy, six.string_types):
-            strategy = get_singleton(strategy, 'cache file strategy')
-        elif isinstance(strategy, dict):
-            strategy = DictStrategy(strategy)
-        elif callable(strategy):
-            strategy = strategy()
-        self._wrapped = strategy
-
-    def __getstate__(self):
-        return {'_wrapped': self._wrapped}
-
-    def __setstate__(self, state):
-        self._wrapped = state['_wrapped']
-
-    def __unicode__(self):
-        return force_text(self._wrapped)
-
-    def __str__(self):
-        return str(self._wrapped)
+def load_strategy(strategy):
+    if isinstance(strategy, six.string_types):
+        strategy = get_singleton(strategy, 'cache file strategy')
+    elif isinstance(strategy, dict):
+        strategy = DictStrategy(strategy)
+    elif callable(strategy):
+        strategy = strategy()
+    return strategy
